Package: ClassComparison
Version: 3.3.5
Date: 2025-02-04
Title: Classes and Methods for "Class Comparison" Problems on
        Microarrays
Authors@R: person(given = c("Kevin", "R."),
                  family = "Coombes",
                  role = c("aut", "cre"),
                  email = "krc@silicovore.com")
Description: Defines the classes used for "class comparison" problems
  in the OOMPA project (<http://oompa.r-forge.r-project.org/>). Class
  comparison includes tests for differential expression; see Simon's
  book for details on typical problem types.
Depends: R (>= 3.0), oompaBase (>= 3.0)
Imports: methods, graphics, stats, splines, Biobase
License: Apache License (== 2.0)
LazyLoad: yes
biocViews: Microarray, DifferentialExpression, MultipleComparisons
URL: http://oompa.r-forge.r-project.org/
NeedsCompilation: no
Packaged: 2025-02-04 21:58:29 UTC; kevin
Author: Kevin R. Coombes [aut, cre]
Maintainer: Kevin R. Coombes <krc@silicovore.com>
Repository: CRAN
Date/Publication: 2025-02-05 08:40:02 UTC
Built: R 4.6.0; ; 2026-04-26 14:41:02 UTC; unix
